@@ -1,19 +1,19 @@
 #' Coerce xml nodes to a list.
 #'
 #' This turns an XML document (or node or nodeset) into the equivalent R
-#' list. Note that this is \code{as_list()}, not \code{as.list()}:
-#' \code{lapply()} automatically calls \code{as.list()} on its inputs, so
+#' list. Note that this is `as_list()`, not `as.list()`:
+#' `lapply()` automatically calls `as.list()` on its inputs, so
 #' we can't override the default.
 #'
-#' \code{as_list} currently only handles the four most common types of
+#' `as_list` currently only handles the four most common types of
 #' children that an element might have:
 #'
 #' \itemize{
 #'   \item Other elements, converted to lists.
 #'   \item Attributes, stored as R attributes. Attributes that have special meanings in R
-#'           (\code{\link{class}}, \code{\link{comment}}, \code{\link{dim}},
-#'           \code{\link{dimnames}}, \code{\link{names}}, \code{\link{row.names}} and
-#'           \code{\link{tsp}}) are escaped with '.'
+#'           ([class()], [comment()], [dim()],
+#'           [dimnames()], [names()], [row.names()] and
+#'           [tsp()]) are escaped with '.'
 #'   \item Text, stored as a character vector.
 #' }
 #'
@@ -52,23 +52,34 @@ as_list.xml_node <- function(x, ns = character(), ...) {
     # Base case - contents
     type <- xml_type(x)
 
-    if (type %in% c("text", "cdata"))
+    if (type %in% c("text", "cdata")) {
       return(xml_text(x))
-    if (type != "element" && type != "document")
+    }
+    if (type != "element" && type != "document") {
       return(paste("[", type, "]"))
+    }
 
     out <- list()
   } else {
-    out <- lapply(seq_along(contents), function(i) as_list(contents[[i]], ns = ns))
+    out <- lapply(seq_along(contents), function(i) {
+      as_list(contents[[i]], ns = ns)
+    })
 
-    nms <- ifelse(xml_type(contents) == "element", xml_name(contents, ns = ns), "")
+    nms <- ifelse(
+      xml_type(contents) == "element",
+      xml_name(contents, ns = ns),
+      ""
+    )
     if (any(nms != "")) {
       names(out) <- nms
     }
   }
 
   # Add xml attributes as R attributes
-  attributes(out) <- c(list(names = names(out)), xml_to_r_attrs(xml_attrs(x, ns = ns)))
+  attributes(out) <- c(
+    list(names = names(out)),
+    xml_to_r_attrs(xml_attrs(x, ns = ns))
+  )
 
   out
 }
@@ -78,7 +89,15 @@ as_list.xml_nodeset <- function(x, ns = character(), ...) {
   lapply(seq_along(x), function(i) as_list(x[[i]], ns = ns))
 }
 
-special_attributes <- c("class", "comment", "dim", "dimnames", "names", "row.names", "tsp")
+special_attributes <- c(
+  "class",
+  "comment",
+  "dim",
+  "dimnames",
+  "names",
+  "row.names",
+  "tsp"
+)
 
 xml_to_r_attrs <- function(x) {
   if (length(x) == 0) {
