@@ -6,7 +6,7 @@ path_to_connection <- function(path, check = c("file", "dir")) {
   }
 
   if (is_url(path)) {
-    if (requireNamespace("curl", quietly = TRUE)) {
+    if (is_installed("curl")) {
       return(curl::curl(path))
     } else {
       return(url(path))
@@ -18,7 +18,8 @@ path_to_connection <- function(path, check = c("file", "dir")) {
   } else {
     path <- file.path(check_path(dirname(path)), basename(path))
   }
-  switch(tools::file_ext(path),
+  switch(
+    tools::file_ext(path),
     gz = gzfile(path, ""),
     bz2 = bzfile(path, ""),
     xz = xzfile(path, ""),
@@ -36,7 +37,6 @@ check_path <- function(path, call = caller_env()) {
     return(normalizePath(path, "/", mustWork = FALSE))
   }
 
-
   msg <- "{.file {path}} does not exist"
   if (!is_absolute_path(path)) {
     msg <- paste0(msg, " in current working directory ({.path {getwd()}})")
@@ -55,7 +55,7 @@ zipfile <- function(path, open = "r") {
   file <- files$Name[[1]]
 
   if (nrow(files) > 1) {
-    message("Multiple files in zip: reading '", file, "'")
+    cli::cli_inform("Multiple files in zip: reading {.file {file}}")
   }
 
   unz(path, file, open = open)
