@@ -1,23 +1,25 @@
-context("xml_structure")
-
 test_that("xml_structure", {
-  expect_output(xml_structure(read_xml("<a><b><c/><c/></b><d/></a>")),
-"<a>
+  expect_output(
+    xml_structure(read_xml("<a><b><c/><c/></b><d/></a>")),
+    "<a>
   <b>
     <c>
     <c>
-  <d>")
+  <d>"
+  )
 
-  expect_output(xml_structure(read_xml("<a><b><c/><c/></b><d/></a>"), indent = 0L),
-"<a>
+  expect_output(
+    xml_structure(read_xml("<a><b><c/><c/></b><d/></a>"), indent = 0L),
+    "<a>
 <b>
 <c>
 <c>
-<d>")
+<d>"
+  )
 })
 
 test_that("xml_structure can write to a file (#244)", {
-  tmp = tempfile()
+  tmp <- tempfile()
   xml_structure(read_xml("<a><b><c/><c/></b><d/></a>"), file = tmp)
   expect_equal(readLines(tmp), c("<a>", "  <b>", "    <c>", "    <c>", "  <d>"))
 
@@ -25,3 +27,10 @@ test_that("xml_structure can write to a file (#244)", {
   xml_structure(read_xml("<a><b><c/><c/></b><d/></a>"), file = tmp)
   expect_equal(readLines(tmp), c("<a>", "  <b>", "    <c>", "    <c>", "  <d>"))
 })
+
+test_that("xml_structure is correct", {
+  x <- read_html(test_path("lego.html.bz2"))
+
+  quicklinks <- xml_find_first(x, "//div[contains(@div, 'quicklinks')]")
+  expect_snapshot(html_structure(quicklinks))
+})
